import { makeStyles } from "@mui/styles"
import { Modal, Collapse } from "antd"
import { DndContext } from '@dnd-kit/core'
import { SortableContext, useSortable, verticalListSortingStrategy } from '@dnd-kit/sortable';
import { CSS } from '@dnd-kit/utilities'
import { arrayMove } from '@dnd-kit/sortable'
import { JSX, useState } from "react"
import { Step } from "../../../interfaces/step";

const useStyle = makeStyles({
    footer: {
        display: 'flex',
        flexDirection: 'row',
    }
})

export interface TaskCreateProps {
    open: boolean,
    set_open: (v: boolean) => void
}

const steps: Step[] = [
    { id: 1, title: '步骤1', type: 'src' } as Step,
    { id: 2, title: '步骤2', type: 'mid' } as Step,
    { id: 2, title: '步骤3', type: 'mid' } as Step,
    { id: 2, title: '步骤4', type: 'mid' } as Step,
    { id: 2, title: '步骤5', type: 'mid' } as Step,
    { id: 2, title: '步骤6', type: 'mid' } as Step,
    { id: 3, title: '步骤7', type: 'dst' } as Step,
]


export const TaskCreate = (props: TaskCreateProps) => {
    const style = useStyle();
    const [items, setItems] = useState(steps);

    const onDragEnd = ({ active, over }) => {
        if (active.id !== over?.id) {
            setItems(items => {
                const oldIndex = items.indexOf(active.id);
                const newIndex = items.indexOf(over.id);
                return arrayMove(items, oldIndex, newIndex);
            });
        }
    };


    return (
        <div>
            <Modal
                width={{
                    xs: '90%',
                    sm: '80%',
                    md: '70%',
                    lg: '60%',
                    xxl: '50%',
                }}
                title="新建任务"
                open={props.open}

                // footer={null}
            >
                <DndContext onDragEnd={onDragEnd}>
                    <SortableContext items={items} strategy={verticalListSortingStrategy}>
                        <Collapse>
                            {items.filter(v => v.type === "mid").map(item => (
                                <SortableItem key={item.id} id={item.id}>
                                    <Collapse.Panel key={item.id} header={item.title}>
                                        步骤内容
                                    </Collapse.Panel>
                                </SortableItem>
                            ))}
                        </Collapse>
                    </SortableContext>
                </DndContext>
            </Modal>
        </div>
    );
};


// Bug fix: Correctly define the type of the children prop to avoid implicit 'any' type
const SortableItem = ({ id, children }: { id: number; children: JSX.Element }) => {
    const { attributes, listeners, setNodeRef, transform, transition } = useSortable({ id });

    const style = {
        transform: CSS.Transform.toString(transform),
        transition,
        cursor: 'move',
        backgroundColor: 'white',
        marginBottom: 8,
        borderRadius: 4,
        boxShadow: '0 2px 4px rgba(0,0,0,0.1)'
    };

    return (
        <div ref={setNodeRef} style={style} {...attributes}>
            <div {...listeners} style={{
                padding: '8px 16px',
                borderRight: '2px solid #1890ff',
                display: 'inline-block',
                marginRight: 16
            }}>⋮⋮</div>
            {children}
        </div>
    );
};